@@ -46,7 +46,7 @@
     }
 
     foreach my $keyfpr (@subvalid_key_fprs) {
-      $keyfpr->{fpr}->as_hex_string() =~ /([[:xdigit:]]{0,40})/;
+      $keyfpr->{fingerprint}->as_hex_string() =~ /([[:xdigit:]]{0,40})/;
       my $fprx = '0x' . $1;
       $logger->log('debug', "checking on %s\n", $fprx);
       foreach my $gpgkey ($gnupg->get_public_keys_with_sigs($fprx)) {
@@ -73,7 +73,7 @@
               if ($cert->hex_id =~ /^([A-Fa-f0-9]{16})$/) {
                 my $certid = $1;
                 # disregard self-certifications (see MS # 2569):
-                if (lc($certid) eq lc(substr($keyfpr->{fpr}->as_hex_string(), -16))) {
+                if (lc($certid) eq lc(substr($keyfpr->{fingerprint}->as_hex_string(), -16))) {
                   $logger->log('debug', "found self-sig 0x%.16s\n", $certid);
                   next;
                 }
@@ -160,7 +160,7 @@ Would you like to temporarily accept this certificate for this peer?",
 Peer's OpenPGP key fingerprint: 0x%.40s
 GnuPG calculated validity for the peer: %s",
                             $uid,
-                            $keyfpr->{fpr}->as_hex_string,
+                            $keyfpr->{fingerprint}->as_hex_string,
                             $keyfpr->{val},
                            );
           # FIXME: what about revoked certifications?
